.. _ansible_roadmaps:

Ansible Roadmap
===============

The Ansible team develops a roadmap for each major and minor Ansible release. The latest roadmap shows current work; older roadmaps provide a history of the project. We don't publish roadmaps for subminor versions. So 2.10 and 2.11 have roadmaps, but 2.10.1 does not.

We incorporate team and community feedback in each roadmap, and aim for further transparency and better inclusion of both community desires and submissions.

Each roadmap offers a *best guess*, based on the Ansible team's experience and on requests and feedback from the community, of what will be included in a given release. However, some items on the roadmap may be dropped due to time constraints, lack of community maintainers, and so on.

Each roadmap is published both as an idea of what is upcoming in Ansible, and as a medium for seeking further feedback from the community.

You can submit feedback on the current roadmap in multiple ways:

- Edit the agenda of an `Ansible Community Meeting <https://github.com/ansible/community/issues/539>`_ (preferred)
- Post on the ``#ansible-community`` chat channel (using Matrix at ansible.im or using IRC at `irc.libera.chat <https://libera.chat/>`_)

See :ref:`Ansible communication channels <communication>` for details on how to join and use our chat channels.

.. toctree::
   :maxdepth: 1
   :glob:
   :caption: Ansible Release Roadmaps

   COLLECTIONS_5
   COLLECTIONS_4
   COLLECTIONS_3_0
   COLLECTIONS_2_10
   old_roadmap_index
